@@ -1,6 +1,8 @@
+#ifndef _SNARECORE_H
+#define _SNARECORE_H
 /**********************************************************
  *
- * Snare for Solaris version 1.5
+ * Snare for Solaris version 2.5.6
  *
  * Author: InterSect Alliance Pty Ltd
  *
@@ -74,6 +76,7 @@
 #include <stdio.h>
 #include <netdb.h>
 #include <signal.h>
+#include <pthread.h>
 #include <limits.h>
 #include <dirent.h>
 
@@ -81,7 +84,6 @@
 
 #include "webserver.h"
 
-
 // Should migrate these to a header.
 
 #define CACHESIZE 2		/* MAX cache size */
@@ -110,6 +112,7 @@
 #define MAX_HOSTID		256		// Host identifier - usually the fully qualified hostname.
 #define MAX_PATH			1024		// PATH_MAX in linux is 4096, but we cannot afford to
 #define MAXCOMMAND 		16
+#define WAITTIME		30			// Time, in seconds, to wait until attempting to send to a dead host
 
 #define CRITICALITY_CLEAR	0
 #define CRITICALITY_INFO	1
@@ -126,6 +129,11 @@
 #define AUDIT_TO_NETWORK        4
 #define AUDIT_TO_SYSLOG         8
 
+#define WEB_CACHE_SIZE 50
+#define DEFAULT_CACHE 320000
+#define SOCKETTYPE_UDP 0
+#define SOCKETTYPE_TCP 1
+
 #define AUDIT_ALL	-1
 
 // Linked List
@@ -148,6 +156,48 @@ struct _node
 
 typedef struct _node Node;
 
+// Linked List
+struct _msgcache {
+	char * msg;
+	int msglen;
+	struct _msgcache *next;
+};
+
+typedef struct _msgcache MsgCache;
+
+struct _webcache {
+	char hostid[MAX_HOSTID];
+	//char string[MAX_AUDITREC];
+	char CurrentDate[16];
+	char username[MAX_USERNAME];
+	char searchterm[MAX_PATH];
+	char eventname[MAX_EVENTNAME];
+	char options[MAX_OPTIONS];
+	int returncode;
+	int criticality;
+	int snareseq;
+	int seenflag;
+	struct _webcache *next;
+	struct _webcache *prev;
+};
+
+typedef struct _webcache WebCache;
+
+struct _hostnode
+{
+	int AuditSocket;
+	struct sockaddr_in      AuditSocketName;
+	socklen_t dest_addr_size;
+	time_t last_error;
+	char desthost[MAX_HOSTID];
+	int port;
+	int protocol;
+	int cacheflag;
+	struct _hostnode *next;
+};
+
+typedef struct _hostnode HostNode;
+
 void	pipe_signal();		/* Routine to handle SIGPIPEs */
 void	kill_signal();		/* Routine to handle SIGTERMs */
 void	usr1_signal();
@@ -199,3 +249,31 @@ char * FindExecArgsToken(char *buffer);
 char * FindAttributeToken(char *buffer);
 
 void DestroyList(void);
+int IsSocketValid(int socket);
+int cachemsg(HostNode *hn, char * msg);
+void purge_cache();
+int fix_last_error(HostNode *hn);
+void start_web ();
+
+// definitions for the ring buffer communication between the auditsvc reader
+//   and the daemon writing to praudit
+
+#define AUDIT_DATA_BLOCK_SIZE 256	// data size of one block within a record
+#define MAX_AUDIT_DATA_BLOCKS 10000	// number of blocks available for records
+
+struct _auditblock
+{
+	unsigned long recordnumber;	// The record number this block belongs to
+	unsigned short numberblocks;	// The amount of blocks belonging to the record
+	unsigned short sequencenumber;	// The sequence number of this block within the record (1-based)
+	unsigned short datalength;	// The data length of this block within the record
+	char data[AUDIT_DATA_BLOCK_SIZE]; // The actual data
+};
+
+typedef struct _auditblock Auditblock;
+
+void RecordToRingbuffer(const char *newrecord, int recordlength,
+					    unsigned long *recordnumber);
+int RecordFromRingbuffer(char *readrecord, unsigned long *recordnumber);
+
+#endif //_SNARECORE_H
