@@ -6,7 +6,8 @@
 #ifndef _WEBSERVER_H_
 #define _WEBSERVER_H_ 1
 
-#define MAX_HTTPBUFFER 8192
+#define MAX_HTTPBUFFER 32768
+#define DNS_CHECK_TIME 1200
 
 #ifdef __linux__
         #define SALT "$1$Snare$"
@@ -20,7 +21,7 @@ void	decodeurl(char *pEncoded);
 int	hex2int(char *pChars);
 int	InitWebServer(unsigned short, char *, char *);
 int	StartThread();
-int	ListenThread();
+int	ListenThread(time_t *);
 int	HandleConnect(void);
 int	CloseWebServer();
 void	RequestAuth(char *HTTPOutputBuffer,int size);
